@@ -1,9 +1,6 @@
 from polars_uuid._register_plugin import is_uuid as is_uuid
 from polars_uuid._register_plugin import u64_pair_to_uuid as u64_pair_to_uuid
 from polars_uuid._register_plugin import uuid_v4 as uuid_v4
-from polars_uuid._register_plugin import uuid_v4_single as uuid_v4_single
 from polars_uuid._register_plugin import uuid_v7 as uuid_v7
 from polars_uuid._register_plugin import uuid_v7_extract_dt as uuid_v7_extract_dt
 from polars_uuid._register_plugin import uuid_v7_now as uuid_v7_now
-from polars_uuid._register_plugin import uuid_v7_now_single as uuid_v7_now_single
-from polars_uuid._register_plugin import uuid_v7_single as uuid_v7_single
