@@ -3,13 +3,12 @@ from __future__ import annotations
 from pathlib import Path
 
 import polars as pl
-from polars.plugins import register_plugin_function
+from polars.plugins import (
+    register_plugin_function,  # pyright: ignore[reportUnknownVariableType]
+)
 
 _LIB = Path(__file__).parent
-_ARGS = pl.repeat(
-    pl.lit("", dtype=pl.String),
-    n=pl.len(),
-)
+_ARGS = pl.first()
 
 _ARGS_SINGLE = pl.lit(None, dtype=pl.Null)
 
@@ -48,7 +47,7 @@ def is_uuid(expr: str | pl.Expr) -> pl.Expr:
         expr = pl.col(expr)
 
     return register_plugin_function(
-        args=(expr,),
+        args=expr,
         plugin_path=_LIB,
         function_name="is_uuid",
         is_elementwise=True,
@@ -86,7 +85,7 @@ def u64_pair_to_uuid(*, high_bits: str | pl.Expr, low_bits: str | pl.Expr) -> pl
 # UUIDv4
 
 
-def uuid_v4() -> pl.Expr:
+def uuid_v4(*, scalar: bool = False) -> pl.Expr:
     """
     Generates a series of random version 4 UUIDs.
 
@@ -96,63 +95,55 @@ def uuid_v4() -> pl.Expr:
     Example:
         >>> df.with_columns(uuid=uuid_v4())
     """
-    return register_plugin_function(
-        args=_ARGS,
-        plugin_path=_LIB,
-        function_name="uuid4_rand",
-        is_elementwise=True,
-    )
+    if scalar:
+        args = _ARGS_SINGLE
+        fn_name = "uuid4_rand_single"
+    else:
+        args = _ARGS
+        fn_name = "uuid4_rand"
 
-
-def uuid_v4_single() -> pl.Expr:
-    """Generates a series filled with the same version 4 UUID."""
     return register_plugin_function(
-        args=_ARGS_SINGLE,
+        args=args,
         plugin_path=_LIB,
-        function_name="uuid4_rand_single",
-        returns_scalar=True,
+        function_name=fn_name,
+        is_elementwise=not scalar,
+        returns_scalar=scalar,
     )
 
 
 # UUIDv7
 
 
-def uuid_v7_now() -> pl.Expr:
+def uuid_v7_now(*, scalar: bool = False) -> pl.Expr:
     """
     Generates a series of random version 7 UUIDs based on the current system time.
 
-    The generated UUIDs are ordered within the resulting series.
-
     Returns:
         pl.Expr: A polars expression of random v7 UUIDs.
 
     Example:
         >>> df.with_columns(uuid=uuid_v7_now())
     """
+    if scalar:
+        args = _ARGS_SINGLE
+        fn_name = "uuid7_rand_now_single"
+    else:
+        args = _ARGS
+        fn_name = "uuid7_rand_now"
+
     return register_plugin_function(
-        args=_ARGS,
+        args=args,
         plugin_path=_LIB,
-        function_name="uuid7_rand_now",
-        is_elementwise=True,
+        function_name=fn_name,
+        is_elementwise=not scalar,
+        returns_scalar=scalar,
     )
 
 
-def uuid_v7_now_single() -> pl.Expr:
-    """Generates a series filled with the same version 7 UUID based on the current system time."""
-    return register_plugin_function(
-        args=_ARGS_SINGLE,
-        plugin_path=_LIB,
-        function_name="uuid7_rand_now_single",
-        returns_scalar=True,
-    )
-
-
-def uuid_v7(*, timestamp: float) -> pl.Expr:
+def uuid_v7(*, timestamp: float, scalar: bool = False) -> pl.Expr:
     """
     Generates a series of random version 7 UUIDs based on the given timestamp.
 
-    The generated UUIDs are ordered within the resulting series.
-
     Parameters:
         timestamp (float): The timestamp to use when generating UUIDs in seconds since the UNIX epoch.
 
@@ -163,26 +154,19 @@ def uuid_v7(*, timestamp: float) -> pl.Expr:
         >>> dt = datetime.datetime(2000, 1, 1, tz=datetime.UTC)
         >>> df.with_columns(uuid=uuid_v7(timestamp=dt.timestamp()))
     """
+    if scalar:
+        args = _ARGS_SINGLE
+        fn_name = "uuid7_rand_single"
+    else:
+        args = _ARGS
+        fn_name = "uuid7_rand"
+
     return register_plugin_function(
-        args=_ARGS,
+        args=args,
         plugin_path=_LIB,
-        function_name="uuid7_rand",
-        is_elementwise=True,
-        kwargs={"seconds_since_unix_epoch": timestamp},
-    )
-
-
-def uuid_v7_single(*, timestamp: float) -> pl.Expr:
-    """Generates a series filled with the same version 7 UUID based on the given timestamp.
-
-    Parameters:
-        timestamp (float): The timestamp to use when generating UUIDs in seconds since the UNIX epoch.
-    """
-    return register_plugin_function(
-        args=_ARGS_SINGLE,
-        plugin_path=_LIB,
-        function_name="uuid7_rand_single",
-        returns_scalar=True,
+        function_name=fn_name,
+        is_elementwise=not scalar,
+        returns_scalar=scalar,
         kwargs={"seconds_since_unix_epoch": timestamp},
     )
 
@@ -211,7 +195,7 @@ def uuid_v7_extract_dt(expr: str | pl.Expr, /, *, strict: bool = True) -> pl.Exp
         expr = pl.col(expr)
 
     return register_plugin_function(
-        args=(expr,),
+        args=expr,
         plugin_path=_LIB,
         function_name="uuid7_extract_dt",
         is_elementwise=True,
