@@ -11,7 +11,6 @@ from polars_uuid import (
     uuid_v7,
     uuid_v7_extract_dt,
     uuid_v7_now,
-    uuid_v7_single,
 )
 
 
@@ -25,20 +24,6 @@ def test_uuid_v7(timestamp: float) -> None:
     assert df["uuid"].dtype == pl.String
     assert df["uuid"].is_unique().all()
     assert df.select(is_uuid("uuid")).to_series().all()
-    assert df["uuid"].is_sorted()
-    assert df["uuid"].str.slice(0, 15).n_unique() == 1
-
-
-@given(st.floats(min_value=0))
-def test_uuid_v7_single(timestamp: float) -> None:
-    df = pl.DataFrame({"idx": list(range(100_000))}).with_columns(
-        uuid=uuid_v7_single(timestamp=timestamp)
-    )
-
-    assert df["uuid"].null_count() == 0
-    assert df["uuid"].dtype == pl.String
-    assert df["uuid"].n_unique() == 1
-    assert df.select(is_uuid("uuid")).to_series().all()
     assert df["uuid"].str.slice(0, 15).n_unique() == 1
 
 
@@ -49,7 +34,6 @@ def test_uuid_v7_now() -> None:
     assert df["uuid"].dtype == pl.String
     assert df["uuid"].is_unique().all()
     assert df.select(is_uuid("uuid")).to_series().all()
-    assert df["uuid"].is_sorted()
     assert df["uuid"].str.slice(0, 15).n_unique() > 1
 
 
